Index: /applications/editors/josm/plugins/ElevationProfile/build.xml
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/build.xml	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/build.xml	(revision 29874)
@@ -4,5 +4,5 @@
     <property name="commit.message" value=""/>
     <!-- enter the *lowest* JOSM version this plugin is currently compatible with -->
-    <property name="plugin.main.version" value="6115"/>
+    <property name="plugin.main.version" value="6162"/>
     
     <!-- Configure these properties (replace "..." accordingly).
Index: /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationProfilePlugin.java
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationProfilePlugin.java	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationProfilePlugin.java	(revision 29874)
@@ -29,54 +29,54 @@
  */
 public class ElevationProfilePlugin extends Plugin {
-	
-	private ElevationMapMode eleMode;
-	private IconToggleButton eleModeButton;
-	private static ElevationProfileLayer currentLayer;
 
-	/**
-	 * Initializes the plugin.
-	 * @param info Context information about the plugin.
-	 */
-	public ElevationProfilePlugin(PluginInformation info) {
-		super(info);
+    private ElevationMapMode eleMode;
+    private IconToggleButton eleModeButton;
+    private static ElevationProfileLayer currentLayer;
 
-		try {
-			eleMode = new ElevationMapMode("Elevation profile", Main.map);
-			eleModeButton = new IconToggleButton(eleMode);
-		} catch (Exception e1) {
-			System.err.println("Init of ElevationProfilePlugin failed: " + e1);
-			e1.printStackTrace();
-		}
+    /**
+     * Initializes the plugin.
+     * @param info Context information about the plugin.
+     */
+    public ElevationProfilePlugin(PluginInformation info) {
+	super(info);
+
+	try {
+	    eleMode = new ElevationMapMode("Elevation profile", Main.map);
+	    eleModeButton = new IconToggleButton(eleMode);
+	} catch (Exception e1) {
+	    System.err.println("Init of ElevationProfilePlugin failed: " + e1);
+	    e1.printStackTrace();
 	}
-	
-	/**
+    }
+
+    /**
      * Called after Main.mapFrame is initialized. (After the first data is loaded).
      * You can use this callback to tweak the newFrame to your needs, as example install
      * an alternative Painter.
      */
-	@Override	
-	public void mapFrameInitialized(MapFrame oldFrame, MapFrame newFrame) {
-		super.mapFrameInitialized(oldFrame, newFrame);
-		
-		if (newFrame != null) {
-			newFrame.addMapMode(eleModeButton);
-			ElevationProfileDialog eleProfileDlg = new ElevationProfileDialog();
-			eleProfileDlg.addModelListener(eleMode);
-			eleProfileDlg.setProfileLayer(getCurrentLayer());
-			newFrame.addToggleDialog(eleProfileDlg);
-		}
+    @Override	
+    public void mapFrameInitialized(MapFrame oldFrame, MapFrame newFrame) {
+	super.mapFrameInitialized(oldFrame, newFrame);
+
+	if (newFrame != null) {
+	    newFrame.addMapMode(eleModeButton);
+	    ElevationProfileDialog eleProfileDlg = new ElevationProfileDialog();
+	    eleProfileDlg.addModelListener(eleMode);
+	    eleProfileDlg.setProfileLayer(getCurrentLayer());
+	    newFrame.addToggleDialog(eleProfileDlg);
 	}
-	
-	/**
-	 * Gets the elevation profile layer which decorates the current layer
-	 * with some markers.
-	 * @return
-	 */
-	public static ElevationProfileLayer getCurrentLayer(){
-		if(currentLayer == null){
-			currentLayer = new ElevationProfileLayer("Elevation profile");
-			Main.main.addLayer(currentLayer);			
-		}
-		return currentLayer;
+    }
+
+    /**
+     * Gets the elevation profile layer which decorates the current layer
+     * with some markers.
+     * @return
+     */
+    public static ElevationProfileLayer getCurrentLayer(){
+	if(currentLayer == null){
+	    currentLayer = new ElevationProfileLayer("Elevation profile");
+	    Main.main.addLayer(currentLayer);			
 	}
+	return currentLayer;
+    }
 }
Index: /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/WayPointHelper.java
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/WayPointHelper.java	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/WayPointHelper.java	(revision 29874)
@@ -119,8 +119,47 @@
 		if (getUnitMode() == UnitMode.Imperial) {
 				// translate to feet
-				return ele * METER_TO_FEET;
+		    return meter2Feet(ele);
 		}	
 		
 		return ele;
+	}
+	
+	/**
+	 * Computes the slope <b>in percent</b> between two way points. E. g. an elevation gain of 12m 
+	 * within a distance of 100m is equal to a slope of 12%. 
+	 *
+	 * @param w1 the first way point
+	 * @param w2 the second way point
+	 * @return the slope in percent
+	 */
+	public static double computeSlope(WayPoint w1, WayPoint w2) {
+	    	// same coordinates? -> return 0, if yes
+	    	if (w1.getCoor().equals(w2.getCoor())) return 0;
+	    
+		// get distance in meters and divide it by 100 in advance
+		double distInMeter = w1.getCoor().greatCircleDistance(w2.getCoor()) / 100.0;
+		
+		// convert to feet?
+		if (getUnitMode() == UnitMode.Imperial) {
+		    distInMeter = meter2Feet(distInMeter);
+		}
+				
+		// get elevation (difference) - is converted automatically to feet
+		int ele1 = (int) WayPointHelper.getElevation(w1);
+		int ele2 = (int) WayPointHelper.getElevation(w2);
+		int dH = ele2 - ele1;
+		
+		// Slope in percent is define as elevation gain/loss in meters related to a distance of 100m
+		return dH / distInMeter;
+	}
+	
+	/**
+	 * Converts meter into feet
+	 *
+	 * @param meter the meter
+	 * @return the double
+	 */
+	public static double meter2Feet(double meter) {
+	    return meter * METER_TO_FEET;
 	}
 	
Index: /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/DefaultElevationProfileRenderer.java
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/DefaultElevationProfileRenderer.java	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/DefaultElevationProfileRenderer.java	(revision 29874)
@@ -52,5 +52,5 @@
 	 * 
 	 */
-	private static final int BASIC_WPT_RADIUS = 2;
+	private static final int BASIC_WPT_RADIUS = 3;
 	private static final int REGULAR_WPT_RADIUS = BASIC_WPT_RADIUS * 4;
 	private static final int BIG_WPT_RADIUS = BASIC_WPT_RADIUS * 10;
@@ -92,4 +92,5 @@
 		switch (kind) {
 		case Plain:
+		    return Color.LIGHT_GRAY;
 		case ElevationLevelLoss:
 		case ElevationLevelGain:
@@ -101,8 +102,12 @@
 		case Highlighted:
 			return Color.ORANGE;
-		case ElevationGain:
-			return Color.GREEN;
-		case ElevationLoss:
-			return Color.RED;
+		case ElevationGainHigh:
+		    	return Color.getHSBColor(0.3f, 1.0f, 1.0f); // green
+		case ElevationLossHigh:
+			return Color.getHSBColor(0, 1.0f, 1.0f); // red
+		case ElevationGainLow:
+		    	return Color.getHSBColor(0.3f, 0.5f, 1.0f); // green with low sat
+		case ElevationLossLow:
+			return Color.getHSBColor(0, 0.5f, 1.0f); // red with low sat
 		case FullHour:
 			return MARKER_POINT;
@@ -116,4 +121,6 @@
 		case EndPoint:
 			return END_POINT;
+		default:
+		    break;
 		}
 
@@ -202,5 +209,5 @@
 			drawLabelWithTriangle(WayPointHelper.getElevationText(ele), pnt.x, pnt.y
 					+ g.getFontMetrics().getHeight(), g, c, 8, 
-					getColorForWaypoint(profile, wpt, ElevationWayPointKind.ElevationGain),
+					getColorForWaypoint(profile, wpt, ElevationWayPointKind.ElevationGainHigh),
 					TriangleDir.Up);
 		}
@@ -209,5 +216,5 @@
 			drawLabelWithTriangle(WayPointHelper.getElevationText(ele), 
 					pnt.x, pnt.y+ g.getFontMetrics().getHeight(), g, c, 8, 
-					getColorForWaypoint(profile, wpt, ElevationWayPointKind.ElevationLoss),
+					getColorForWaypoint(profile, wpt, ElevationWayPointKind.ElevationLossHigh),
 					TriangleDir.Down);
 		}
@@ -392,5 +399,5 @@
 				- (radius * 0.6f));
 		float[] dist = { 0.1f, 0.2f, 1.0f };
-		Color[] colors = { firstCol, secondCol, Color.BLACK };
+		Color[] colors = { firstCol, secondCol, Color.DARK_GRAY };
 		RadialGradientPaint p = new RadialGradientPaint(center, radius, focus,
 				dist, colors, CycleMethod.NO_CYCLE);
Index: /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/ElevationProfileLayer.java
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/ElevationProfileLayer.java	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/gui/ElevationProfileLayer.java	(revision 29874)
@@ -43,199 +43,225 @@
 public class ElevationProfileLayer extends
 org.openstreetmap.josm.gui.layer.Layer implements IElevationProfileSelectionListener {
-	private static final double Level_Factor = 100.0;
-	private IElevationProfile profile;
-	private IElevationProfileRenderer renderer = new DefaultElevationProfileRenderer();
-	private WayPoint selWayPoint = null;	
-
-	/**
-	 * Creates a new elevation profile layer
-	 * 
-	 * @param name
-	 *            The name of the layer.
-	 */
-	public ElevationProfileLayer(String name) {
-		super(name);
+    private static final double Level_Factor = 100.0;
+    private IElevationProfile profile;
+    private IElevationProfileRenderer renderer = new DefaultElevationProfileRenderer();
+    private WayPoint selWayPoint = null;	
+
+    /**
+     * Creates a new elevation profile layer
+     * 
+     * @param name
+     *            The name of the layer.
+     */
+    public ElevationProfileLayer(String name) {
+	super(name);
+    }
+
+    /**
+     * Gets the current elevation profile shown in this layer.
+     * 
+     * @return
+     */
+    public IElevationProfile getProfile() {
+	return profile;
+    }
+
+    /**
+     * Sets the current elevation profile shown in this layer.
+     * 
+     * @param profile
+     *            The profile to show in the layer
+     */
+    public void setProfile(IElevationProfile profile) {
+	this.profile = profile;
+	Main.map.repaint();
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.openstreetmap.josm.gui.layer.Layer#getIcon()
+     */
+    @Override
+    public Icon getIcon() {
+	return ImageProvider.get("layer", "elevation_small");
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.openstreetmap.josm.gui.layer.Layer#getInfoComponent()
+     */
+    @Override
+    public Object getInfoComponent() {
+	return getToolTipText();
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.openstreetmap.josm.gui.layer.Layer#getMenuEntries()
+     */
+    @Override
+    public Action[] getMenuEntries() {
+	// TODO: More entries???
+	return new Action[] { new LayerListPopup.InfoAction(this) };
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.openstreetmap.josm.gui.layer.Layer#getToolTipText()
+     */
+    @Override
+    public String getToolTipText() {
+	if (profile != null) {
+	    return tr("Elevation profile for track ''{0}''.", profile.getName());
+	} else {
+	    return tr("Elevation profile");
 	}
-
-	/**
-	 * Gets the current elevation profile shown in this layer.
-	 * 
-	 * @return
-	 */
-	public IElevationProfile getProfile() {
-		return profile;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.openstreetmap.josm.gui.layer.Layer#isMergable(org.openstreetmap.josm
+     * .gui.layer.Layer)
+     */
+    @Override
+    public boolean isMergable(Layer other) {
+	return false;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.openstreetmap.josm.gui.layer.Layer#mergeFrom(org.openstreetmap.josm
+     * .gui.layer.Layer)
+     */
+    @Override
+    public void mergeFrom(Layer from) {
+	// nothing to do
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.openstreetmap.josm.gui.layer.Layer#paint(java.awt.Graphics2D,
+     * org.openstreetmap.josm.gui.MapView, org.openstreetmap.josm.data.Bounds)
+     */
+    @Override
+    public void paint(Graphics2D g, MapView mv, Bounds box) {
+	WayPoint lastWpt = null;
+	int lastEle = 0;
+
+	renderer.beginRendering();
+	if (profile != null) {			
+	    // paint way points one by one
+	    for (WayPoint wpt : profile.getWayPoints()) {
+		
+
+		if (lastWpt != null) {
+		    // determine way point
+		    ElevationWayPointKind kind = classifyWayPoint(lastWpt, wpt);
+
+		    // render way point
+		    renderer.renderWayPoint(g, profile, mv, wpt, kind);
+		} // else first way point -> is paint later
+
+		// remember some things for next iteration
+		lastEle = (int) WayPointHelper.getElevation(wpt);
+		lastWpt = wpt;
+	    }
+
+	    // now we paint special way points in emphasized style 
+
+	    // paint selected way point, if available
+	    if (selWayPoint != null) {
+		renderer.renderWayPoint(g, profile, mv, selWayPoint,
+			ElevationWayPointKind.Highlighted);
+	    }
+
+	    // paint start/end
+	    renderer.renderWayPoint(g, profile, mv, profile.getStartWayPoint(),
+		    ElevationWayPointKind.StartPoint);
+	    renderer.renderWayPoint(g, profile, mv, profile.getEndWayPoint(),
+		    ElevationWayPointKind.EndPoint);
+	    // paint min/max
+	    renderer.renderWayPoint(g, profile, mv, profile.getMaxWayPoint(),
+		    ElevationWayPointKind.MaxElevation);
+	    renderer.renderWayPoint(g, profile, mv, profile.getMinWayPoint(),
+		    ElevationWayPointKind.MinElevation);
+	} 
+
+	renderer.finishRendering();
+    }
+
+    /**
+     * Checks if the given way point requires special decoration (e. g. elevation gain/loss or level crossing).
+     * 
+     * Parameters <tt>ele1</tt> and <tt>ele2</tt> point are used for detecting "level crossings",
+     * e. g. 1 to 2 indicate that we crossed the 200m elevation in upward direction
+     *
+     * @param lastWpt the last way point
+     * @param actWpt the actual way point 
+     * @return the elevation way point kind
+     */
+    private ElevationWayPointKind classifyWayPoint(WayPoint lastWpt, WayPoint actWpt) {
+	// get elevation values
+	int actEle = (int) WayPointHelper.getElevation(actWpt);
+	int lastEle = (int) WayPointHelper.getElevation(lastWpt);
+	
+	// normalize elevation to levels
+	int actLevel = (int)(actEle / Level_Factor);
+	int lastLevel = (int)(lastEle / Level_Factor);
+	double slope = Math.abs(WayPointHelper.computeSlope(lastWpt, actWpt));
+
+	// plain way point by default
+	ElevationWayPointKind kind = ElevationWayPointKind.Plain;
+	System.out.println("Slope: " + slope + "%");
+	
+	// check, if we passed an elevation level
+	// We assume, that we cannot pass more than one levels between two way points ;-)
+	if (actLevel != lastLevel && Math.abs(actLevel - lastLevel) == 1) { 
+	    if (actLevel > lastLevel) { // we went down?		
+		kind =ElevationWayPointKind.ElevationLevelGain; 
+	    } else {
+		kind =ElevationWayPointKind.ElevationLevelLoss;
+	    }
+	} else { // check for elevation gain or loss
+	    if (actEle > lastEle) { // we went uphill?
+		// TODO: Provide parameters for high/low thresholds
+		if (slope > 3) kind =ElevationWayPointKind.ElevationGainLow;
+		if (slope > 10) kind =ElevationWayPointKind.ElevationGainHigh;
+	    } else {
+		if (slope > 3) kind =ElevationWayPointKind.ElevationLossLow;
+		if (slope > 10) kind =ElevationWayPointKind.ElevationLossHigh;
+	    }
 	}
-
-	/**
-	 * Sets the current elevation profile shown in this layer.
-	 * 
-	 * @param profile
-	 *            The profile to show in the layer
-	 */
-	public void setProfile(IElevationProfile profile) {
-		this.profile = profile;
-		Main.map.repaint();
+	return kind;
+    }
+    
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.openstreetmap.josm.gui.layer.Layer#visitBoundingBox(org.openstreetmap
+     * .josm.data.osm.visitor.BoundingXYVisitor)
+     */
+    @Override
+    public void visitBoundingBox(BoundingXYVisitor v) {
+	// TODO Auto-generated method stub
+    }
+
+    @Override
+    public void selectedWayPointChanged(WayPoint newWayPoint) {
+	if (selWayPoint != newWayPoint) {
+	    selWayPoint = newWayPoint;
+	    Main.map.repaint();
 	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.openstreetmap.josm.gui.layer.Layer#getIcon()
-	 */
-	@Override
-	public Icon getIcon() {
-		return ImageProvider.get("layer", "elevation_small");
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.openstreetmap.josm.gui.layer.Layer#getInfoComponent()
-	 */
-	@Override
-	public Object getInfoComponent() {
-		return getToolTipText();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.openstreetmap.josm.gui.layer.Layer#getMenuEntries()
-	 */
-	@Override
-	public Action[] getMenuEntries() {
-		// TODO: More entries???
-		return new Action[] { new LayerListPopup.InfoAction(this) };
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.openstreetmap.josm.gui.layer.Layer#getToolTipText()
-	 */
-	@Override
-	public String getToolTipText() {
-		if (profile != null) {
-			return tr("Elevation profile for track ''{0}''.", profile.getName());
-		} else {
-			return tr("Elevation profile");
-		}
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see
-	 * org.openstreetmap.josm.gui.layer.Layer#isMergable(org.openstreetmap.josm
-	 * .gui.layer.Layer)
-	 */
-	@Override
-	public boolean isMergable(Layer other) {
-		return false;
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see
-	 * org.openstreetmap.josm.gui.layer.Layer#mergeFrom(org.openstreetmap.josm
-	 * .gui.layer.Layer)
-	 */
-	@Override
-	public void mergeFrom(Layer from) {
-		// nothing to do
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.openstreetmap.josm.gui.layer.Layer#paint(java.awt.Graphics2D,
-	 * org.openstreetmap.josm.gui.MapView, org.openstreetmap.josm.data.Bounds)
-	 */
-	@Override
-	public void paint(Graphics2D g, MapView mv, Bounds box) {
-		WayPoint lastWpt = null;
-		int lastEle = 0;
-
-		renderer.beginRendering();
-		if (profile != null) {			
-			// paint way points one by one
-			for (WayPoint wpt : profile.getWayPoints()) {
-				int ele = (int) WayPointHelper.getElevation(wpt);
-
-				if (lastWpt != null) {
-					// normalize to levels
-					int ele1 = (int)(ele / Level_Factor);
-					int ele2 = (int)(lastEle / Level_Factor);
-					
-					// plain way point by default
-					ElevationWayPointKind kind = ElevationWayPointKind.Plain;
-					// check, if we passed an elevation level
-					// We assume, that we cannot pass more than one levels between two way points ;-)
-					if (ele1 != ele2 && Math.abs(ele1 - ele2) == 1) { 
-						if (ele1 > ele2) { // we went down?
-							kind =ElevationWayPointKind.ElevationLevelGain; 
-						} else {
-							kind =ElevationWayPointKind.ElevationLevelLoss;
-						}
-					} else { // check for elevation gain or loss
-						if (ele > lastEle) { // we went down?
-							kind =ElevationWayPointKind.ElevationGain;
-						} else {
-							kind =ElevationWayPointKind.ElevationLoss;
-						}
-					}
-					
-					// render way point
-					renderer.renderWayPoint(g, profile, mv, wpt, kind);
-				}
-
-				// remember some things for next iteration
-				lastEle = (int) WayPointHelper.getElevation(wpt);
-				lastWpt = wpt;
-			}
-			
-			// now we paint special way points in emphasized style 
-			
-			// paint selected way point, if available
-			if (selWayPoint != null) {
-				renderer.renderWayPoint(g, profile, mv, selWayPoint,
-						ElevationWayPointKind.Highlighted);
-			}
-
-			// paint start/end
-			renderer.renderWayPoint(g, profile, mv, profile.getStartWayPoint(),
-					ElevationWayPointKind.StartPoint);
-			renderer.renderWayPoint(g, profile, mv, profile.getEndWayPoint(),
-					ElevationWayPointKind.EndPoint);
-			// paint min/max
-			renderer.renderWayPoint(g, profile, mv, profile.getMaxWayPoint(),
-					ElevationWayPointKind.MaxElevation);
-			renderer.renderWayPoint(g, profile, mv, profile.getMinWayPoint(),
-					ElevationWayPointKind.MinElevation);
-		} 
-		
-		renderer.finishRendering();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see
-	 * org.openstreetmap.josm.gui.layer.Layer#visitBoundingBox(org.openstreetmap
-	 * .josm.data.osm.visitor.BoundingXYVisitor)
-	 */
-	@Override
-	public void visitBoundingBox(BoundingXYVisitor v) {
-		// TODO Auto-generated method stub
-	}
-
-	@Override
-	public void selectedWayPointChanged(WayPoint newWayPoint) {
-		if (selWayPoint != newWayPoint) {
-			selWayPoint = newWayPoint;
-			Main.map.repaint();
-		}
-	}
+    }
 
 }

Index: /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationWayPointKind.java
===================================================================
--- /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationWayPointKind.java	(revision 29873)
+++ /applications/editors/josm/plugins/ElevationProfile/src/org/openstreetmap/josm/plugins/elevation/ElevationWayPointKind.java	(revision 29874)
@@ -20,12 +20,14 @@
  */
 public enum ElevationWayPointKind {
-	Plain, 				// Simple way point
-	Highlighted,		// Highlighted waypoint
+	Plain, 				// Simple way point (equal to no or low slope)
+	Highlighted,			// Highlighted waypoint
 	StartPoint,			// First way point
 	EndPoint,			// Last way point
-	MaxElevation,		// Highest way point
-	MinElevation,		// Lowest way point 
-	ElevationGain,		// Elevation gain
-	ElevationLoss,		// Elevation loss	
+	MaxElevation,			// Highest way point
+	MinElevation,			// Lowest way point 
+	ElevationGainHigh,		// Elevation gain (high slope 15-25%)
+	ElevationLossHigh,		// Elevation loss (high downward slope)
+	ElevationGainLow,		// Elevation gain (low slope, 5-14.9%)
+	ElevationLossLow,		// Elevation loss (low downward slope)
 	ElevationLevelGain,		// Elevation level gain (e. g. crossed 300m from lower elevation)
 	ElevationLevelLoss,		// Elevation level (e. g. crossed 300m from higher elevation)